@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## Class Objects - ~/lib/Class.pm
-## Version v1.1.3
+## Version v1.1.4
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/02/27
@@ -22,7 +22,7 @@ BEGIN
     our @EXPORT = @Module::Generic::EXPORT;
     our @EXPORT_OK = @Module::Generic::EXPORT_OK;
     our %EXPORT_TAGS = %Module::Generic::EXPORT_TAGS;
-    our $VERSION = 'v1.1.3';
+    our $VERSION = 'v1.1.4';
 };
 
 sub import
@@ -111,13 +111,13 @@ Support for legacy code:
 
 =head1 VERSION
 
-    v1.1.3
+    v1.1.4
 
 =head1 DESCRIPTION
 
 This package inherits all its features from L<Module::Generic> and provides a generic framework of methods to inherit from and speed up development.
 
-It also provide support for legacy code whereby C<CLASS> and C<$CLASS> are both synonyms for C<__PACKAGE__>.  Easier to type.
+It also provides support for legacy code whereby C<CLASS> and C<$CLASS> are both synonyms for C<__PACKAGE__>.  Easier to type.
 
 C<$CLASS> has the additional benefit of working in strings.
 
